% Generated by roxygen2 (4.0.1): do not edit by hand
\name{block}
\alias{block}
\alias{blockslice}
\alias{getscales}
\alias{oaatslice}
\title{Slice sampling in blocks}
\usage{
blockslice(blocks, scale = 1, m = Inf, rand = TRUE)

oaatslice(d, ...)

getscales(obj)
}
\arguments{
\item{blocks}{list of blocks, forming a partition of \code{1:d}}

\item{scale}{initial scale, either common or one for each block}

\item{m}{maximum number of stepping out steps, can be \code{Inf} (same for each block)}

\item{rand}{process blocks in random order?  See Details.}

\item{d}{number of components in the random vector}

\item{...}{arguments for \code{blockslice}}

\item{obj}{Function returned by \code{\link{slice}}, \code{blockslice}, or \code{oaatslice}}
}
\value{
\code{blockslice} and \code{ooatslice} have the same return
value as \code{\link{slice}}.

\code{getscales} is a utility function to extract the scales from a
function returned by \code{slice} (scalar), \code{blockslice} (one
per block), or \code{ooatslice} (one per component).
}
\description{
Handle the case where different blocks of the random
vector have different scales.  This is a wrapper for
\code{\link{slice}}.
}
\details{
If \code{rand = TRUE}, the blocks are processed in random
order, which ensures that the sampler is reversible. Reversible
samplers have more attractive theoretical (convergence) properties;
see Besag et al (1995).

\code{oaatslice} is just a wrapper for \code{blockslice}, where each component is in a block of one ('one at a time').  This allows each component to have its own scale.  But this approach will not respond very well in situations where two or more components with similar scales are strongly correlated (in which case they should be in the same block).
}
\examples{
## Similar example to 'slice', but making a weird distribution with
## identical margins

mylogf <- function(x) {
  sum(dnorm(x, log = TRUE)) + log(sum(x) <= 0)
}

myslice <- blockslice(list(1, c(2, 4), c(3, 5, 6))) # or oaatslice(6) for individual scales
N <- 1e3
rsam <- matrix(NA, N, 6)
spinup <- 1e2

x <- rep(-1, 6)
for (loop in (-spinup + 1):N) {
  x <- myslice(x, mylogf, learn = (loop <= 0))
  if (loop > 0) rsam[loop, ] <- x
}
print(all(rowSums(rsam) <= 0)) # TRUE
pairs(rsam, xlim = c(-3, 3), ylim = c(-3, 3))

## check the margins against each other (nb blocks are /not/ symmetrical)

mvqqplot(rsam, rsam[, c(2:6, 1)])
mvqqplot(rsam, rsam[, c(2:6, 1)], list(2:3, 2:4, 2:5, 2:6, 1:6))

## comparison sample by rejection sampling

rsam1 <- matrix(rnorm(2 * N * 6), ncol = 6)
keep <- rowSums(rsam1) <= 0
rsam1 <- rsam1[keep, ]

mvqqplot(rsam, rsam1)
mvqqplot(rsam, rsam1[, c(2:6, 1)])
mvqqplot(rsam, rsam1, list(2, 2:3, 2:4, 1:4))

## looks OK!

print(getscales(myslice)) # should be about the same

#### sample from a level set of the constrained banana function

mylogf <- function(x, theta) {
    log(banana(x, theta) <= 100) +
        log(-1.5 <= x[1] && x[1] <= 2.0) +
            log(-1.0 <= x[2] && x[2] <= 3)
}

x <- seq(from = -2, to = 2.5, length = 101)
y <- seq(from = -1.5, to = 3.5, length = 101)
z <- apply(as.matrix(expand.grid(x, y)), 1, mylogf, theta = 100)
dim(z) <- c(length(x), length(y))
image(x, y, z)

myslice <- oaatslice(2)
N <- 1e3
rsam <- matrix(NA, N, 2)
spinup <- 1e2

x <- rep(0, 2)
for (loop in (-spinup + 1):N) {
    x <- myslice(x, mylogf, learn = (loop <= 0), theta = 100)
    if (loop > 0) rsam[loop, ] <- x
}
points(rsam, pch = 20, cex = 0.7)
}
\author{
Jonathan Rougier <j.c.rougier@bristol.ac.uk>
}
\references{
J. Besag, P. Green, D. Higdon, and K. Mengersen, 1995,
Bayesian Computation and Stochastic Systems, Statistical Science
10(1), 3-66.
}
\seealso{
\code{\link{slice}} for explanations of the \code{scale}
and \code{m} arguments.
}

