% Generated by roxygen2 (4.0.1): do not edit by hand
\name{mvqqplot}
\alias{banana}
\alias{mvqqplot}
\title{qqplot for two multivariate datasets}
\usage{
mvqqplot(X, Y, subsets = as.list(1L:p), N = 200, trim = 0.1)

banana(x, theta = 100)
}
\arguments{
\item{X,Y}{two matrices with the same number of columns (\code{p})}

\item{subsets}{list of margins to plot}

\item{N}{number of points to show (see Details)}

\item{trim}{drop the \code{trim} largest points (proportion), which tend to be very variable in qqplots.}

\item{x}{arguments to Rosenbrock banana function}

\item{theta}{coefficient in Rosenbrock banana function}
}
\value{
Invoked for its side-effect, of creating a set of qqplots
of the specified functions.
}
\description{
Take two matrices and display a set of qqplots for
specified functions of their columns, as a quick way of assessing
whether they represent samples from similar distributions.  The
functions are slices through the p-dimensional Rosenbrock banana
function, where p is the (common) number of columns in the two
matrices.  The default is to look at the p axial slices, but other
margins can be specified: see the Example for \code{\link{slice}}.
}
\details{
If the number of rows of the two matrices differ, then the larger matrix is reduced by resampling its rows.  Both matrices are reduced by resampling to \code{N} rows if the smaller matrix has at least \code{N} rows.

The Rosenbrock banana function with parameter \eqn{\theta} is defined as
\deqn{\sum_{i=1}^{p-1} [ (1 - x_i)^2 + \theta \times (x_{i+1} - x_i^2)^2 ] }
See \url{http://en.wikipedia.org/wiki/Rosenbrock_function} for more details.  The log of the banana function is simply used here as an interesting non-linear function of several variables.
}
\examples{
## Here are some samples from the same distribution

A <- matrix(c(1, -1, 1, 2), ncol = 2)
X <- matrix(70 + rnorm(200), ncol = 2) \%*\% A
Y <- matrix(70 + rnorm(250), ncol = 2) \%*\% A
mvqqplot(X, Y) # do this a few times to see sampling variation
mvqqplot(X, Y, list(1, 2, c(1, 2))) # see other margins

## And here are some from different distributions

Y <- matrix(65 + rt(250, df = 3), ncol = 2) \%*\% A
mvqqplot(X, Y) # Yikes!
mvqqplot(X, Y, list(1, 2, c(1, 2)))
}
\author{
Jonathan Rougier <j.c.rougier@bristol.ac.uk>
}
\seealso{
\code{\link{qqplot}} for one-dimensional comparisons.
}

